@@ -25,6 +25,8 @@ class SkillsNetworkEdxMiddleware(object):
         print(environ)
         print(environ.get("RELEASE_NAME"))
         print("processing response")
+        with open("/tmp/test", "w") as f:
+            f.write("test\n")
         return response
 
     def process_exception(self, request, exception):
